# LaTeX2HTML 2002-2-1 (1.71)
# Associate images original text with physical files.


$key = q/geq;MSF=1.5;AAT/;
$cached_env_img{$key} = q|<IMG
 WIDTH="16" HEIGHT="27" ALIGN="MIDDLE" BORDER="0"
 SRC="|."$dir".q|img1.gif"
 ALT="$ \geq$">|; 

1;

